There would an aiommy description.
Something about how to use and what is it for.

# TODO:
  test installing
  refactoring

  license
  makefile
  travis

  responses
  validators
  views

  other extensions for peewee
